==> haskell-regex-tdfa-1.2.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
key: regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.Tester
    Text.Regex.TDFA.NewDFA.Uncons Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: e7a54c355a04842b33f052c4e32e7e7a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-tdfa-1.2.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    ghc-prim-0.5.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.2.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-ITZHc3hWBSU2Doba6qXtEU
key: regex-tdfa-1.2.2-ITZHc3hWBSU2Doba6qXtEU
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.Tester
    Text.Regex.TDFA.NewDFA.Uncons Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: 9f113a55b726b8951e373120aecb5173
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-tdfa-1.2.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-ITZHc3hWBSU2Doba6qXtEU
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    ghc-prim-0.5.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
